package api.txInfo

import android.content.ContentValues.TAG
import android.content.Context
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.*
import com.bumptech.glide.Glide
import com.idotools.sdk.gdt.R
import com.qq.e.ads.ContentAdType
import com.qq.e.ads.contentad.ContentAdData
import com.qq.e.ads.contentad.ContentData
import com.qq.e.ads.contentad.ContentType
import com.qq.e.ads.nativ.MediaListener
import com.qq.e.ads.nativ.MediaView
import com.qq.e.ads.nativ.NativeMediaADData
import com.qq.e.comm.constants.AdPatternType
import com.qq.e.comm.util.AdError
import java.util.*

class InfoAdapter(val context: Context, valdata: List<ContentAdData>, val listView: ListView) : BaseAdapter() {
    private var mInflater: LayoutInflater? = null
    private var mData: List<ContentAdData>? = null// 要显示的数据
    private var contentAdDataMap = HashMap<Int, ContentAdData>()
    init {
        this.mInflater = LayoutInflater.from(context)
        this.mData = valdata
    }


    override fun getItemViewType(position: Int): Int {
        return mData!![position].type.ordinal
    }

    override fun getViewTypeCount(): Int {
        return 2
    }

    override fun getCount(): Int {
        return if (mData == null) {
            0
        } else {
            mData!!.size
        }
    }

    override fun getItem(i: Int): Any {
        return mData!![i]
    }

    override fun getItemId(i: Int): Long {
        return i.toLong()
    }

    override fun getView(position: Int, convertView: View?, viewGroup: ViewGroup): View {
        var convertView = convertView
        val contentAdData = mData!![position]
        var viewHolder: ViewHolder? = null
        contentAdDataMap[position] = contentAdData
        if (convertView == null || convertView.tag == null) {
            viewHolder = ViewHolder()
            convertView = this.mInflater!!.inflate(R.layout.listi_tem, null, false)
            viewHolder!!.mediaView = convertView!!.findViewById(R.id.media_view) as MediaView
            viewHolder!!.imgLogo = convertView.findViewById(R.id.img) as ImageView
            viewHolder!!.textName = convertView.findViewById(R.id.title) as TextView
            viewHolder!!.textDesc = convertView.findViewById(R.id.from) as TextView
            convertView!!.tag = viewHolder
        } else {
            viewHolder = convertView.tag as ViewHolder
        }
        if (contentAdData.type == ContentAdType.AD) {
            val nativeADDataRef = contentAdData as NativeMediaADData
            Glide.with(context).load(nativeADDataRef.iconUrl).into(viewHolder!!.imgLogo!!)
            viewHolder!!.textName!!.text = nativeADDataRef.title
            viewHolder!!.textDesc!!.text = nativeADDataRef.desc
            viewHolder!!.mediaView!!.visibility = View.GONE
            if (nativeADDataRef.adPatternType == AdPatternType.NATIVE_VIDEO && nativeADDataRef.isVideoLoaded) {
                if (nativeADDataRef.isPlaying) {
                    viewHolder!!.mediaView!!.visibility = View.VISIBLE
                } else {
                    viewHolder!!.mediaView!!.visibility = View.VISIBLE
                    nativeADDataRef.bindView(viewHolder!!.mediaView, true) // 只有将MediaView和广告实例绑定之后，才能播放视频
                    nativeADDataRef.play()
                    /** 设置视频播放过程中的监听器  */
                    nativeADDataRef.setMediaListener(object : MediaListener {

                        /**
                         * 视频播放器初始化完成，准备好可以播放了
                         *
                         * @param videoDuration 视频素材的总时长
                         */
                        override fun onVideoReady(videoDuration: Long) {
                            Log.i(TAG, "onVideoReady, videoDuration = $videoDuration")
                        }

                        /** 视频开始播放  */
                        override fun onVideoStart() {
                            Log.i(TAG, "onVideoStart")
                        }

                        /** 视频暂停  */
                        override fun onVideoPause() {
                            Log.i(TAG, "onVideoPause")
                        }

                        /** 视频自动播放结束，到达最后一帧  */
                        override fun onVideoComplete() {
                            Log.i(TAG, "onVideoComplete")
                        }

                        /** 视频播放时出现错误  */
                        override fun onVideoError(error: AdError) {
                            Log.i(TAG, "onVideoError, errorCode: " + error.errorCode)
                        }

                        /** SDK内置的播放器控制条中的重播按钮被点击  */
                        override fun onReplayButtonClicked() {
                            Log.i(TAG, "onReplayButtonClicked")
                        }

                        /**
                         * SDK内置的播放器控制条中的下载/查看详情按钮被点击 注意:
                         * 这里是指UI中的按钮被点击了，而广告的点击事件回调是在onADClicked中，开发者如需统计点击只需要在onADClicked回调中进行一次统计即可。
                         */
                        override fun onADButtonClicked() {
                            Log.i(TAG, "onADButtonClicked")
                        }

                        /** SDK内置的全屏和非全屏切换回调，进入全屏时inFullScreen为true，退出全屏时inFullScreen为false  */
                        override fun onFullScreenChanged(inFullScreen: Boolean) {
                            Log.i(TAG, "onFullScreenChanged, inFullScreen = $inFullScreen")
                            // 原生视频广告默认静音播放，进入到全屏后建议开发者可以设置为有声播放
                            if (inFullScreen) {
                                nativeADDataRef.setVolumeOn(true)
                            } else {
                                nativeADDataRef.setVolumeOn(false)
                            }
                        }
                    })
                }
            }

            val v = convertView.findViewById(R.id.ad_info) as RelativeLayout
            nativeADDataRef.onExposured(v) // 需要先调用曝光接口
            v.setOnClickListener { nativeADDataRef.onClicked(it) }
        } else if (contentAdData.type == ContentAdType.INFORMATION) {
            val contentData = contentAdData as ContentData
            Glide.with(context).load(contentData.images[0]).into(viewHolder!!.imgLogo!!)
            viewHolder!!.textName!!.text = contentData.title
            if (contentData.contentType == ContentType.ARTICLE) {
                viewHolder!!.textDesc!!.text = contentData.from + "   " + contentData.elapseTime
            } else if (contentData.contentType == ContentType.VIDEO) {
                viewHolder!!.textDesc!!.text = contentData.from + "   " + contentData.label
            }
            val v = convertView.findViewById(R.id.contentContainer) as RelativeLayout
            contentData.onExpouse(v) // 需要先调用曝光接口
            v.setOnClickListener {
                contentData.onClick(it) }
        }
        return convertView
    }


    fun onScroll() {
        val first = listView.firstVisiblePosition
        val last = listView.lastVisiblePosition-1
        for (i in first..last) {
            if (isAd(i) && (mData!![i] as NativeMediaADData).adPatternType == AdPatternType.NATIVE_VIDEO && (mData!![i] as NativeMediaADData).isVideoLoaded) {
                (mData!![i] as NativeMediaADData).onScroll(i, listView)
            }
        }
    }

    private fun isAd(position: Int): Boolean {
        return mData!![position].type == ContentAdType.AD
    }

    inner class ViewHolder {
        internal var imgLogo: ImageView? = null
        internal var textName: TextView? = null
        internal var textDesc: TextView? = null
        internal var mediaView: MediaView? = null
    }
}